from typing import List

from rdflib import Graph

from ..ns import *
from ..l0.Concept import Concept
from .Email import Email


class EmailType(Concept):
    __type__ = SM["EmailType"]

    isEmailTypeOf: List[Email] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isEmailTypeOf:
            for isEmailTypeOf in self.isEmailTypeOf:
                g.add((self.uriRef, SM["isEmailTypeOf"], isEmailTypeOf.uriRef))



from typing import List

from rdflib import Graph, Literal

from ..ns import *
from .AdminUnitComponent import AdminUnitComponent


class Province(AdminUnitComponent):
    __type__ = CLV["Province"]

    acronym: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.acronym:
            for acronym in self.acronym:
                g.add((self.uriRef, CLV["acronym"], acronym))



from typing import List

from rdflib import Graph, Literal

from ..ns import *
from ..l0.Description import Description


class Rating(Description):
    __type__ = SM["Rating"]

    bestUserRating: List[Literal] = None
    worstUserRating: List[Literal] = None
    userRating: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.bestUserRating:
            for bestUserRating in self.bestUserRating:
                g.add((self.uriRef, SM["bestUserRating"], bestUserRating))

        if self.worstUserRating:
            for worstUserRating in self.worstUserRating:
                g.add((self.uriRef, SM["worstUserRating"], worstUserRating))

        if self.userRating:
            g.add((self.uriRef, SM["userRating"], self.userRating))



from rdflib import URIRef

from ..l0.Characteristic import Characteristic
from ..ns import *


class ParticipationType(Characteristic):
    __type__ = COV["ParticipationType"]


class Direct(ParticipationType):
    def __init__(self):
        self.uriRef = URIRef(COV["Direct"])


class Indirect(ParticipationType):
    def __init__(self):
        self.uriRef = URIRef(COV["Indirect"])



from typing import List

from rdflib import Graph

from ..clv.Address import Address
from ..ns import *
from .AlivePerson import AlivePerson
from .Family import Family


class Resident(AlivePerson):
    __type__ = CPV["Resident"]

    belongsToFamily: List[Family] = None
    hasCurrentResidence: Address = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.belongsToFamily:
            for belongsToFamily in self.belongsToFamily:
                g.add((self.uriRef, CPV["belongsToFamily"], belongsToFamily))

        if self.hasCurrentResidence:
            g.add(self.uriRef, CPV["hasCurrentResidence"],
                  self.hasCurrentResidence.uriRef)



from typing import List

from rdflib import Graph, Literal

from ..clv.Address import Address
from ..clv.Identifier import Identifier
from ..l0.Location import Location
from ..ns import *
from ..sm.Image import Image
from ..sm.OnlineContactPoint import OnlineContactPoint
from ..Thing import Thing
from .ActivityType import ActivityType
from .BalanceSheet import BalanceSheet
from .ChangeEvent import ChangeEvent
from .declarations.Organization import Organization
from .Employment import Employment
from .LegalStatus import LegalStatus
from .SupportUnit import SupportUnit


class Organization(Organization):
    __type__ = COV["Organization"]

    hasSpatialCoverage: List[Location] = None
    changedBy: List[ChangeEvent] = None
    hasActivityType: List[ActivityType] = None
    hasAlternativeIdentifier: List[Identifier] = None
    hasBalanceSheet: List[BalanceSheet] = None
    holdEmployment: List[Employment] = None
    participating: List[Organization] = None
    resultedFrom: List[ChangeEvent] = None
    hasPrimaryAddress: Address = None
    hasLegalStatus: LegalStatus = None
    hasOnlineContactPoint: OnlineContactPoint = None
    hasLogo: Image = None
    legalName: List[Literal] = None
    description: List[Literal] = None
    mainFunction: List[Literal] = None
    taxCode: Literal = None
    accreditationDate: Literal = None
    altName: Literal = None
    foundationDate: Literal = None
    orgAcronym: Literal = None
    follows: List[Organization] = None
    hasSupportUnit: List[SupportUnit] = None
    hasSubOrganization: List[Organization] = None
    isOrganizationOf: List[Thing] = None
    precedes: List[Organization] = None
    subOrganizationOf: List[Organization] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasSpatialCoverage:
            for hasSpatialCoverage in self.hasSpatialCoverage:
                g.add(
                    (self.uriRef, CLV["hasSpatialCoverage"], hasSpatialCoverage.uriRef))

        if self.changedBy:
            for changedBy in self.changedBy:
                g.add((self.uriRef, COV["changedBy"], changedBy.uriRef))

        if self.hasActivityType:
            for hasActivityType in self.hasActivityType:
                g.add(
                    (self.uriRef, COV["hasActivityType"], hasActivityType.uriRef))

        if self.hasAlternativeIdentifier:
            for hasAlternativeIdentifier in self.hasAlternativeIdentifier:
                g.add(
                    (self.uriRef, COV["hasAlternativeIdentifier"], hasAlternativeIdentifier.uriRef))

        if self.hasBalanceSheet:
            for hasBalanceSheet in self.hasBalanceSheet:
                g.add(
                    (self.uriRef, COV["hasBalanceSheet"], hasBalanceSheet.uriRef))

        if self.holdEmployment:
            for holdEmployment in self.holdEmployment:
                g.add(
                    (self.uriRef, COV["holdEmployment"], holdEmployment.uriRef))

        if self.participating:
            for participating in self.participating:
                g.add(
                    (self.uriRef, COV["participating"], participating.uriRef))

        if self.resultedFrom:
            for resultedFrom in self.resultedFrom:
                g.add((self.uriRef, COV["resultedFrom"], resultedFrom.uriRef))

        if self.legalName:
            for legalName in self.legalName:
                g.add((self.uriRef, COV["legalName"], legalName))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.mainFunction:
            for mainFunction in self.mainFunction:
                g.add((self.uriRef, COV["mainFunction"], mainFunction))

        if self.follows:
            for follows in self.follows:
                g.add((self.uriRef, COV["follows"], follows.uriRef))

        if self.hasSupportUnit:
            for hasSupportUnit in self.hasSupportUnit:
                g.add(
                    (self.uriRef, COV["hasSupportUnit"], hasSupportUnit.uriRef))

        if self.hasSubOrganization:
            for hasSubOrganization in self.hasSubOrganization:
                g.add(
                    (self.uriRef, COV["hasSubOrganization"], hasSubOrganization.uriRef))

        if self.isOrganizationOf:
            for isOrganizationOf in self.isOrganizationOf:
                g.add(
                    (self.uriRef, COV["isOrganizationOf"], isOrganizationOf.uriRef))

        if self.precedes:
            for precedes in self.precedes:
                g.add((self.uriRef, COV["precedes"], precedes.uriRef))

        if self.subOrganizationOf:
            for subOrganizationOf in self.subOrganizationOf:
                g.add(
                    (self.uriRef, COV["subOrganizationOf"], subOrganizationOf.uriRef))

        if self.hasPrimaryAddress:
            g.add((self.uriRef, CLV["hasPrimaryAddress"],
                  self.hasPrimaryAddress.uriRef))

        if self.hasLegalStatus:
            g.add((self.uriRef, COV["hasLegalStatus"],
                  self.hasLegalStatus.uriRef))

        if self.hasOnlineContactPoint:
            g.add((self.uriRef, SM["hasOnlineContactPoint"],
                  self.hasOnlineContactPoint.uriRef))

        if self.hasLogo:
            g.add((self.uriRef, COV["hasLogo"], self.hasLogo.uriRef))

        if self.taxCode:
            g.add((self.uriRef, COV["taxCode"], self.taxCode))

        if self.accreditationDate:
            g.add(
                (self.uriRef, COV["accreditationDate"], self.accreditationDate))

        if self.altName:
            g.add((self.uriRef, COV["altName"], self.altName))

        if self.foundationDate:
            g.add((self.uriRef, COV["foundationDate"], self.foundationDate))

        if self.orgAcronym:
            g.add((self.uriRef, COV["orgAcronym"], self.orgAcronym))



from rdflib import Graph, Literal

from ..l0.Object import Object
from ..ns import *


class eInvoiceService(Object):
    __type__ = COV["eInvoiceService"]

    eInvoiceServiceStartingDate: Literal = None
    taxCodeEInvoiceService: Literal = None
    taxCodeValidationDate: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.eInvoiceServiceStartingDate:
            g.add(self.uriRef, COV["eInvoiceServiceStartingDate"],
                  self.eInvoiceServiceStartingDate)

        if self.taxCodeEInvoiceService:
            g.add(self.uriRef, COV["taxCodeEInvoiceService"],
                  self.taxCodeEInvoiceService)

        if self.taxCodeValidationDate:
            g.add(self.uriRef, COV["taxCodeValidationDate"],
                  self.taxCodeValidationDate)



from typing import List

from rdflib import Graph

from ..ns import *
from .declarations.AddressComponent import AddressComponent


class AddressComponent(AddressComponent):
    __type__ = CLV["AddressComponent"]

    situatedWithin: List[AddressComponent] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.situatedWithin:
            for situatedWithin in self.situatedWithin:
                g.add(
                    (self.uriRef, CLV["situatedWithin"], situatedWithin.uriRef))



from typing import List

from rdflib import Graph

from ..ns import *
from ..Thing import Thing
from ..ti.TimeInterval import TimeInterval
from .declarations.Address import Address
from .declarations.AddressInTime import AddressInTime


class AddressInTime(AddressInTime):
    __type__ = CLV["AddressInTime"]

    atTime: List[TimeInterval] = None
    nextAddress: List[AddressInTime] = None
    prevAddress: List[AddressInTime] = None
    withAddress: Address = None
    withAddress: List[Thing] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.atTime:
            for atTime in self.atTime:
                g.add(
                    (self.uriRef, CLV["atTime"], atTime.uriRef))

        if self.nextAddress:
            for nextAddress in self.nextAddress:
                g.add(
                    (self.uriRef, CLV["nextAddress"], nextAddress.uriRef))

        if self.prevAddress:
            for prevAddress in self.prevAddress:
                g.add(
                    (self.uriRef, CLV["prevAddress"], prevAddress.uriRef))

        if self.isAddressInTimeFor:
            for isAddressInTimeFor in self.isAddressInTimeFor:
                g.add(
                    (self.uriRef, CLV["isAddressInTimeFor"], isAddressInTimeFor.uriRef))

        if self.withAddress:
            g.add((self.uriRef, CLV["withAddress"], self.withAddress.uriRef))



from rdflib import Graph, Literal

from ..ns import *
from .Object import Object


class Description(Object):
    __type__ = L0["Description"]

    description: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.description:
            g.add((self.uriRef, L0["description"], self.description))



from typing import List

from rdflib import Graph, Literal

from ..l0.Characteristic import Characteristic
from ..ns import *


class Sex(Characteristic):
    __type__ = CPV["Sex"]

    sexDesc: List[Literal] = None
    sexID: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.sexDesc:
            for sexDesc in self.sexDesc:
                g.add((self.uriRef, CLV["sexDesc"], sexDesc))

        if self.sexID:
            g.add(self.uriRef, CPV["sexID"], self.sexID)



from typing import List

from rdflib import Graph

from ..ns import *
from ..l0.Object import Object
from ..accesscondition.AccessCondition import AccessCondition


class ContactPoint(Object):
    __type__ = SM["ContactPoint"]

    available: List[AccessCondition] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.available:
            for available in self.available:
                g.add((self.uriRef, SM["available"], available.uriRef))



from typing import List

from rdflib import Graph

from ..ns import *
from .Person import Person


class FamilySheetHolder(Person):
    __type__ = CPV["FamilySheetHolder"]

    isFamilySheetHolderOf: List[Person] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isFamilySheetHolderOf:
            for isFamilySheetHolderOf in self.isFamilySheetHolderOf:
                g.add(
                    (self.uriRef, CPV["isFamilySheetHolderOf"], isFamilySheetHolderOf.uriRef))



from typing import List

from rdflib import Graph

from ..ns import *
from ..l0.EventOrSituation import EventOrSituation
from .TimeInterval import TimeInterval


class TimeIndexedEvent(EventOrSituation):
    __type__ = TI["TimeIndexedEvent"]

    atTime: List[TimeInterval] = []

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        for atTime in self.atTime:
            g.add((self.uriRef, TI["atTime"], atTime.uriRef))



from typing import List

from rdflib import Graph, Literal

from ..ns import *
from .AddressComponent import AddressComponent


class AdminUnitComponent(AddressComponent):
    __type__ = CLV["AdminUnitComponent"]

    name: List[Literal] = None
    hasDirectHigherRank: List[AddressComponent] = None
    hasDirectLowerRank: List[AddressComponent] = None
    hasHigherRank: List[AddressComponent] = None
    hasLowerRank: List[AddressComponent] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))

        if self.hasDirectHigherRank:
            for hasDirectHigherRank in self.hasDirectHigherRank:
                g.add(
                (self.uriRef, CLV["hasDirectHigherRank"], hasDirectHigherRank))

        if self.hasDirectLowerRank:
            for hasDirectLowerRank in self.hasDirectLowerRank:
                g.add((self.uriRef, CLV["hasDirectLowerRank"], hasDirectLowerRank))

        if self.hasHigherRank:
            for hasHigherRank in self.hasHigherRank:
                g.add((self.uriRef, CLV["hasHigherRank"], hasHigherRank))

        if self.hasLowerRank:
            for hasLowerRank in self.hasLowerRank:
                g.add((self.uriRef, CLV["hasLowerRank"], hasLowerRank))



from .Activity import Activity
from .Agent import Agent
from .Characteristic import Characteristic
from .Collection import Collection
from .Concept import Concept
from .Description import Description
from .Entity import Entity
from .EventOrSituation import EventOrSituation
from .Location import Location
from .Object import Object
from .Sequence import Sequence
from .System import System
from .Topic import Topic


from .Address import Address
from .AddressArea import AddressArea
from .AddressComponent import AddressComponent
from .AddressInTime import AddressInTime
from .AdminUnitComponent import AdminUnitComponent
from .CensusSection import CensusSection
from .City import City
from .CivicNumbering import CivicNumbering
from .Country import Country
from .District import District
from .Feature import Feature
from .GeographicalDistribution import GeographicalDistribution
from .Geometry import Geometry
from .GeometryType import GeometryType
from .Identifier import Identifier
from .InternalAccess import InternalAccess
from .Province import Province
from .Region import Region
from .SpatialObject import SpatialObject
from .StreetToponym import StreetToponym


from rdflib import URIRef

from ..l0.Characteristic import Characteristic
from ..ns import *


class Status(Characteristic):
    __type__ = COV["Status"]


class Cancelled(Status):
    def __init__(self):
        self.uriRef = URIRef(COV["Cancelled"])


class Registered(Status):
    def __init__(self):
        self.uriRef = URIRef(COV["Registered"])


class UnderRegistration(Status):
    def __init__(self):
        self.uriRef = URIRef(COV["UnderRegistration"])



from typing import List

from rdflib import Graph, Literal

from ..ns import *
from .AddressArea import AddressArea
from .AddressComponent import AddressComponent
from .AddressInTime import AddressInTime
from .CensusSection import CensusSection
from .City import City
from .CivicNumbering import CivicNumbering
from .Country import Country
from .declarations.Address import Address
from .District import District
from .InternalAccess import InternalAccess
from .Province import Province
from .Region import Region
from .StreetToponym import StreetToponym
from ..cpv.Person import Person


class Address(Address):
    __type__ = CLV["Address"]

    hasAddressComponent: List[AddressComponent] = None
    hasInternalAccess: List[InternalAccess] = None
    hasNumber: CivicNumbering = None
    hasStreetToponym: StreetToponym = None
    hasAdressinTime: AddressInTime = None
    hasCensusSection: CensusSection = None
    fullAddress: Literal = None
    postCode: Literal = None
    hasAddressArea: List[AddressArea] = None
    hasCity: List[City] = None
    hasCountry: List[Country] = None
    hasDistrict: List[District] = None
    hasProvince: List[Province] = None
    hasRegion: List[Region] = None
    isCurrentResidenceOf: List[Person] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasAddressComponent:
            for hasAddressComponent in self.hasAddressComponent:
                g.add(
                    (self.uriRef, CLV["hasAddressComponent"], hasAddressComponent.uriRef))

        if self.hasInternalAccess:
            for hasInternalAccess in self.hasInternalAccess:
                g.add(
                    (self.uriRef, CLV["hasInternalAccess"], hasInternalAccess.uriRef))

        if self.hasNumber:
            g.add((self.uriRef, CLV["hasNumber"], self.hasNumber.uriRef))

        if self.hasStreetToponym:
            g.add((self.uriRef, CLV["hasStreetToponym"],
                  self.hasStreetToponym.uriRef))

        if self.hasAdressinTime:
            g.add((self.uriRef, CLV["hasAdressinTime"],
                  self.hasAdressinTime.uriRef))

        if self.hasCensusSection:
            g.add((self.uriRef, CLV["hasCensusSection"],
                  self.hasCensusSection.uriRef))

        if self.fullAddress:
            g.add((self.uriRef, CLV["fullAddress"], self.fullAddress))

        if self.postCode:
            g.add((self.uriRef, CLV["postCode"], self.postCode))

        if self.hasAddressArea:
            for hasAddressArea in self.hasAddressArea:
                g.add(
                    (self.uriRef, CLV["hasAddressArea"], hasAddressArea.uriRef))

        if self.hasCity:
            for hasCity in self.hasCity:
                g.add(
                    (self.uriRef, CLV["hasCity"], hasCity.uriRef))

        if self.hasCountry:
            for hasCountry in self.hasCountry:
                g.add(
                    (self.uriRef, CLV["hasCountry"], hasCountry.uriRef))

        if self.hasDistrict:
            for hasDistrict in self.hasDistrict:
                g.add(
                    (self.uriRef, CLV["hasDistrict"], hasDistrict.uriRef))

        if self.hasProvince:
            for hasProvince in self.hasProvince:
                g.add(
                    (self.uriRef, CLV["hasProvince"], hasProvince.uriRef))

        if self.hasRegion:
            for hasRegion in self.hasRegion:
                g.add(
                    (self.uriRef, CLV["hasRegion"], hasRegion.uriRef))

        if self.isCurrentResidenceOf:
            for isCurrentResidenceOf in self.isCurrentResidenceOf:
                g.add(
                    (self.uriRef, CPV["isCurrentResidenceOf"], isCurrentResidenceOf.uriRef))